@@ -12,7 +12,7 @@ use Date::Calc            qw/Delta_Days/;
 use Carp                  qw/croak/;
 use Encode                qw/encode_utf8/;
 
-my $VERSION = '0.4';
+our $VERSION = '0.6';
 
 #======================================================================
 # GLOBALS
@@ -37,6 +37,10 @@ my %params_spec = (
  );
 
 
+my %entity       = ( '<' => '&lt;', '>' => '&gt;', '&' => '&amp;' );
+my $entity_regex = do {my $chars = join "", keys %entity; qr/[$chars]/};
+
+
 #======================================================================
 # CONSTRUCTOR
 #======================================================================
@@ -132,7 +136,7 @@ sub add_sheet {
       (my $tag, my $attrs, $val)
         = looks_like_number $val             ? (v => ""                  , $val                          )
         : $date_regex && $val =~ $date_regex ? (v => qq{ s="$DATE_STYLE"}, n_days($+{y}, $+{m}, $+{d})   )
-        : $val =~ s/^=//                     ? (f => "",                   $val                          )
+        : $val =~ /^=/                       ? (f => "",                   escape_formula($val)          )
         :                                      (v => qq{ t="s"}          , $self->add_shared_string($val));
 
       # add the new XML cell
@@ -455,19 +459,26 @@ sub n_tables {
 #======================================================================
 
 
-my %entity = ( '<' => '&lt;', '>' => '&gt;', '&' => '&amp;' );
-
 sub si_node {
   my ($string) = @_;
 
   # build XML node for a single shared string
-  $string =~ s/([<>&])/$entity{$1}/eg;
+  $string =~ s/($entity_regex)/$entity{$1}/g;
   my $maybe_preserve_space = $string =~ /^\s|\s$/ ? ' xml:space="preserve"' : '';
   my $node = qq{<si><t$maybe_preserve_space>$string</t></si>};
 
   return $node;
 }
 
+sub escape_formula {
+  my ($string) = @_;
+
+  $string =~ s/^=//;
+  $string =~ s/($entity_regex)/$entity{$1}/g;
+  return $string;
+}
+
+
 sub n_days {
   my ($y, $m, $d) = @_;
 
